==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/sr.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Управљање Лигхтбок ГАЛЛАРИ Параметри");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "upravljanje Галлери");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Већа слика Ширина");
define('MANAGE_GALLERY_FULL_HEIGHT', "Већа слика Висина");
define('MANAGE_GALLERY_THUMB_WIDTH', "Тхумбнаил Слика Ширина");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Тхумбнаил Слика Висина");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Сачувати Тхумб Аспецт Ратио");
define('MANAGE_GALLERY_SHOW_TITLES', "Схов Наслови");
define('MANAGE_GALLERY_DISABLE_SORT', "дисабле Сортирај");
define('MANAGE_GALLERY_DELETE_IMAGE', "Делете Имаге");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Саве Сорт Ордер");
define('MANAGE_GALLERY_PUBLISH_MSG', "Кликните на &quot;Упдате&quot; да објави <br /> Отпремљени слике.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Све слике су смањене и поставке су сачуване.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Дошло је до грешке промена величине слике или подешавања за чување.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ваша слика (е) је објављено.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Дошло је до грешке отпремање слика (слике).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Датотека коју покушавате да отпремите није слика.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Датотека коју покушавате да отпремите је превелика.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Наслов је сачуван.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Да ли сте сигурни да желите да избришете слику");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Слика је избрисана.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Дошло је до грешке приликом брисања слику.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Чување параметара и промена величине слике, сачекајте ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Уплоадинг, сачекајте ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Редослед сортирања није сачуван. Да ли желите да сачувате сортирања?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "слика врста Редослед је сачувана.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Дошло је до грешке при чувању слике врсту.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/sr.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Управљање Лигхтбок ГАЛЛАРИ Параметри");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "upravljanje Галлери");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Већа слика Ширина");
define('MANAGE_GALLERY_FULL_HEIGHT', "Већа слика Висина");
define('MANAGE_GALLERY_THUMB_WIDTH', "Тхумбнаил Слика Ширина");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Тхумбнаил Слика Висина");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Сачувати Тхумб Аспецт Ратио");
define('MANAGE_GALLERY_SHOW_TITLES', "Схов Наслови");
define('MANAGE_GALLERY_DISABLE_SORT', "дисабле Сортирај");
define('MANAGE_GALLERY_DELETE_IMAGE', "Делете Имаге");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Саве Сорт Ордер");
define('MANAGE_GALLERY_PUBLISH_MSG', "Кликните на &quot;Упдате&quot; да објави <br /> Отпремљени слике.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Све слике су смањене и поставке су сачуване.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Дошло је до грешке промена величине слике или подешавања за чување.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ваша слика (е) је објављено.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Дошло је до грешке отпремање слика (слике).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Датотека коју покушавате да отпремите није слика.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Датотека коју покушавате да отпремите је превелика.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Наслов је сачуван.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Да ли сте сигурни да желите да избришете слику");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Слика је избрисана.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Дошло је до грешке приликом брисања слику.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Чување параметара и промена величине слике, сачекајте ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Уплоадинг, сачекајте ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Редослед сортирања није сачуван. Да ли желите да сачувате сортирања?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "слика врста Редослед је сачувана.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Дошло је до грешке при чувању слике врсту.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Датотека коју покушавате да пошаљете већа је од „уплоад_мак_филесизе“ или „пост_мак_сизе“ поставки ПХП-а. Да бисте повећали та ограничења, обратите се администратору система.");
?>
